@@ -3,13 +3,14 @@ use strict;
 use warnings;
 
 use Fennec::Util qw/accessors get_test_call/;
+use Scalar::Util qw/blessed/;
 
 accessors qw/name out/;
 
 sub TIEHANDLE {
     my $class = shift;
-    my ( $name, $out ) = @_;
-    return bless( { name => $name, out => $out }, $class );
+    my ( $name ) = @_;
+    return bless( { name => $name }, $class );
 }
 
 sub PRINT {
@@ -18,9 +19,17 @@ sub PRINT {
     my @call = get_test_call();
     my $out  = $self->out;
 
-    for my $output ( @_ ) {
-        print $out join( "\0", $$, $self->name, $call[0], $call[1], $call[2], $_ ) . "\n"
-            for split( /[\n\r]+/, $output );
+    for my $output ( @data ) {
+        my @serialized = map {
+            join( "\0", $$, $self->name, $call[0], $call[1], $call[2], $_ ) . "\n"
+        } split /[\n\r]+/, $output;
+
+        if (blessed $out && $out->isa( 'Fennec::Listener::TB::Collector' )) {
+            $out->process( $_ ) for @serialized;
+        }
+        else {
+            print $out @serialized;
+        }
     }
 }
 
